@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION);
 use Carp;
 use DBI;
-$VERSION = '0.85';
+$VERSION = '0.86';
 
 # Default options for the module
 my %DefaultOptions = (
@@ -65,11 +65,14 @@ sub TIEHASH {
 	%DefaultOptions,
 	defined($opt) ? %$opt : ()
 	};
+    bless $self,$class;
+
     my ($dbh,$driver);
 
     if (UNIVERSAL::isa($dsn,'DBI::db')) {
 	$dbh = $dsn;
 	$driver = $dsn->{Driver}{Name};
+	$dbh->{Warn} = $self->{WARN};
     } else {
 	$dsn = "dbi:$dsn" unless $dsn=~ /^dbi/;
 	($driver) = $dsn =~ /\w+:(\w+)/;
@@ -85,7 +88,7 @@ sub TIEHASH {
 			       }
 			      );
 	$self->{needs_disconnect}++;
-	croak "TIEHASH: Can't open $dsn, ",$self->errstr unless $dbh;
+	croak "TIEHASH: Can't open $dsn, ",$class->errstr unless $dbh;
       }
 
     # set up more instance variables
@@ -96,7 +99,7 @@ sub TIEHASH {
     $self->{NoQuote}       = $NO_QUOTE{$driver};
     $self->{DoesIN}        = $DOES_IN{$driver};
 
-    return bless $self,$class;
+    return $self;
 }
 
 sub DESTROY {
@@ -192,7 +195,7 @@ sub EXISTS {
     $st->fetch;
     my $rows = $st->rows;
     $st->finish;
-    $rows != 0;
+    $rows > 0;
 }
 
 sub CLEAR {
@@ -253,7 +256,10 @@ sub STORE {
 	    $s->_update($key,\@fields,\@values)
 		:  $s->_insert($key,\@fields,\@values);
     } else {
-	$result = $s->_update($key,\@fields,\@values) || $s->_insert($key,\@fields,\@values);
+      my $errors;
+      $errors = $s->{'dbh'}->{PrintError} if $s->{'needs_disconnect'};  # not ours
+      $result = $s->_insert($key,\@fields,\@values) || $s->_update($key,\@fields,\@values);
+      $s->{'dbh'}->{PrintError} = $errors if $s->{'needs_disconnect'};  # not ours
     }
     croak "STORE: ",$s->errstr if $s->error;
 
@@ -324,7 +330,7 @@ sub _run_query {
     if ($self->{CanBind}) {
 	unless (!$self->{CanBindSelect} && $query=~/\bwhere\b/i) {
 	    my $sth = $self->_prepare($tag,$query);
-	    return undef unless $sth->execute(@bind_variables);
+	    return unless $sth->execute(@bind_variables);
 	    return $sth;
 	}
     }
@@ -333,7 +339,7 @@ sub _run_query {
     $query =~ s/\?/defined($_ = shift(@bind_variables)) ? $_ : 'null'/eg;
 
     my $sth = $self->{'dbh'}->prepare($query);
-    return undef unless $sth && $sth->execute;
+    return unless $sth && $sth->execute;
     return $sth;
 }
 
@@ -413,8 +419,8 @@ sub _update {
     $key = $s->_quote($s->{key},$key) unless $s->{CanBindSelect};
     local($") = ',';
     my $st = $s->_run_query("update@$fields",
-			  "update $s->{table} set @set where $s->{key}=?",@values,$key);
-    return $st ? $st->rows : 0;
+			    "update $s->{table} set @set where $s->{key}=?",@values,$key);
+    return $st ? $st->rows : undef;
 }
 
 sub _quote_many {
@@ -780,6 +786,20 @@ Field names work in much the same way:
      print "There are $quantity apricots at $price each";
          => There are 2 apricots at 0.85 each";
 
+Note that this takes advantage of a bit of Perl syntactic sugar which
+automagically treats $h{'a','b','c'} as if the keys were packed
+together with the $; pack character.  Be careful not to fall into this
+trap:
+
+
+     $result = $h{join( ',', 'apricots', 'bananas' )};
+         => undefined
+
+What you really want is this:
+
+     $result = $h{join( $;, 'apricots', 'bananas' )};
+         => ARRAY(0x828a8ac)
+
 =head2 Updating information
 
 If CLOBBER is set to a non-zero value (and the underlying database
